summaryrefslogtreecommitdiff
path: root/gtk2_ardour/imageframe_time_axis.cc
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/imageframe_time_axis.cc')
-rw-r--r--gtk2_ardour/imageframe_time_axis.cc14
1 files changed, 6 insertions, 8 deletions
diff --git a/gtk2_ardour/imageframe_time_axis.cc b/gtk2_ardour/imageframe_time_axis.cc
index 3b3d9bffde..9a870a915a 100644
--- a/gtk2_ardour/imageframe_time_axis.cc
+++ b/gtk2_ardour/imageframe_time_axis.cc
@@ -32,7 +32,6 @@
#include "public_editor.h"
#include "imageframe_time_axis.h"
-#include "simplerect.h"
#include "enums.h"
#include "imageframe_time_axis_view.h"
#include "imageframe_time_axis_group.h"
@@ -41,7 +40,6 @@
#include "marker_time_axis.h"
#include "marker_view.h"
#include "gui_thread.h"
-#include "canvas_impl.h"
#include "i18n.h"
@@ -142,18 +140,18 @@ ImageFrameTimeAxis::set_height (uint32_t h)
}
/**
* Sets the number of samples per unit that are used.
* This is used to determine the siezes of items upon this time axis
*
* @param spu the number of samples per unit
*/
void
-ImageFrameTimeAxis::set_samples_per_unit(double spu)
+ImageFrameTimeAxis::set_frames_per_pixel (double fpp)
{
- TimeAxisView::set_samples_per_unit (editor.get_current_zoom());
+ TimeAxisView::set_frames_per_pixel (editor.get_current_zoom ());
- if(view) {
- view->set_samples_per_unit(spu) ;
+ if (view) {
+ view->set_frames_per_pixel (fpp);
}
}
@@ -142,18 +140,18 @@ ImageFrameTimeAxis::set_height (uint32_t h)
}
/**
- * Sets the number of samples per unit that are used.
+ * Sets the number of frames per pixel that are used.
* This is used to determine the siezes of items upon this time axis
*
@@ -142,18 +140,18 @@ ImageFrameTimeAxis::set_height (uint32_t h)
* This is used to determine the siezes of items upon this time axis
*
- * @param spu the number of samples per unit
+ * @param fpp the number of frames per pixel
*/
void